<div align="center">
  <img width="200" height="200"
    src="https://s3.amazonaws.com/pix.iemoji.com/images/emoji/apple/ios-11/256/crayon.png">
  <h1>@jimp/jpeg</h1>
  <p>Default Jimp jpeg encoder/decoder.</p>
</div>

## Available Methods

### Jimp.quality

Sets the quality of the image when saving as JPEG format (default is 100)
